function Supplementary_Code_1       
% Author: Marco Albrecht
% Last change: 04.10.2018
% Reproduced paper:
% "Population Pharmacokinetics of Dabrafenib, a BRAF Inhibitor: Effect of Dose, Time, Covariates, and Relationship With Its Metabolites"
%  Daniele Ouellet, Ekaterina Gibiansky, Cathrine Leonowens, Anne OHagan, Patricia Haney, Julie Switzky, Vicki L. Goodman
%% clean
clear all; close all; clc; 

%% Parameter definition
p.VcF    =  70.3       ;% [L]   apparent volume of central compartment
p.VpF    = 154.0       ;% [L]   apparent volume of peripheral compartment
p.QF     =   3.3       ;% [L/h] apparent inter-compartmental clearence
p.tlag   =   0.482     ;% [h]   absorption lag-time
p.Ka     =   1.88      ;% [L/h] absorption rate constant
p.CL0F   =  17.0       ;% [L/h] apparent initial clearence
p.CLindSS=  17.3       ;% [L/h] apparent inducible clearence at steady state
p.Dref   = 150.0       ;% [mg]  reference dose
p.Fgel   =   0.555     ;% [-]   relative bioavailability of gelatin capsule to HPMC capsule
p.y      =   0.927     ;% [-]   power of dependence of CLindSS on absorbed dose (LDOS X Fgel)
p.T50    =  67.3       ;% [h]   half-live of clearence induction
p.tmax   =  24*30      ;% [h]   simulation time
%% Initial condition
c0    = [0 0];             % start values
tspan = [0 p.tmax];            % Zeitintervall
options = odeset ;%('Refine',100);

%% 150 mg BID dabrafenib
p.D = 150 ;%Dose Dabrafenib
for i = 1:((p.tmax+p.tlag)/12+1)
if i==1
    tspan=[0,p.tlag];
       c0=[0 0];
[t1,c1]   = ode15s(@dabra,tspan,c0,options,p);
else
    tspan=[((i-2)*12+p.tlag),((i-1)*12+p.tlag)];
        co=[c1(end,1)  c1(end,2)];
[t11,c11] = ode15s(@dabra,tspan,co,options,p); 
t1=[t1(1:end-1); t11];
c1=[c1(1:end-1,:); c11];
end
end
   

%% 100 mg BID dabrafenib
p.D = 100 ;%Dose Dabrafenib
for i = 1:((p.tmax+p.tlag)/12+1)
if i==1
    tspan=[0,p.tlag];
       c0=[0 0];
[t2,c2] = ode15s(@dabra,tspan,c0,options,p);
else
    tspan=[((i-2)*12+p.tlag),((i-1)*12+p.tlag)];
    co=[c2(end,1)  c2(end,2)];
[t22,c22] = ode15s(@dabra,tspan,co,options,p); 
t2=[t2(1:end-1); t22];
c2=[c2(1:end-1,:); c22];
end
end


%% 75 mg BID dabrafenib
p.D = 75 ;%Dose Dabrafenib
for i = 1:((p.tmax+p.tlag)/12+1)
if i==1
    tspan=[0,p.tlag];
       c0=[0 0];
[t3,c3] = ode15s(@dabra,tspan,c0,options,p);
else
    tspan=[((i-2)*12+p.tlag),((i-1)*12+p.tlag)];
    co=[c3(end,1)  c3(end,2)];
[t33,c33] = ode15s(@dabra,tspan,co,options,p); 
t3=[t3(1:end-1); t33];
c3=[c3(1:end-1,:); c33];
end
end

%% 50 mg BID dabrafenib
p.D = 50 ;%Dose Dabrafenib
for i = 1:((p.tmax+p.tlag)/12+1)
if i==1
    tspan=[0,p.tlag];
       c0=[0 0];
[t4,c4] = ode15s(@dabra,tspan,c0,options,p);
else
    tspan=[((i-2)*12+p.tlag),((i-1)*12+p.tlag)];
    co=[c4(end,1)  c4(end,2)];
[t44,c44] = ode15s(@dabra,tspan,co,options,p); 
t4=[t4(1:end-1); t44];
c4=[c4(1:end-1,:); c44];
end
end


h1=figure(1)
x0=10;
y0=10;
width=40*25;
height=30*25;
set(gcf,'units','points','position',[x0,y0,width,height]);
set(gcf,'color','w');

subplot(3,10,[1 2 11 12 21 22])
ylim([-100 1690])
xlim([0 (12+p.tlag)])
hold on
plot(t1,c1(:,1)*1000,'black', t1,c1(:,2)*1000,'black','Linewidth',2);
plot(t2,c2(:,1)*1000,'--b', t2,c2(:,2)*1000,'--b','Linewidth',2);
plot(t3,c3(:,1)*1000,':r', t3,c3(:,2)*1000,':r','Linewidth',2);
plot(t4,c4(:,1)*1000,'-.y', t4,c4(:,2)*1000,'-.y','Linewidth',2);

xlabel('Time [h]');
ylabel('Concentration [ng/mL]');
title('PK of Dabrafenib');
legend('150 mg BID,central','150 mg BID,peripheral','100 mg BID,central','100 mg BID,peripheral','75 mg BID,central','75 mg BID,peripheral','50 mg BID,central','50 mg BID,peripheral','location','Southoutside');
yyaxis right
ylim([-100 1690]/0.51956)
ylabel('Concentration [nM]');
grid on;

subplot(3,10,[7 8 9 10])
%locs
t1a=t1/24;
t2a=t2/24;
t3a=t3/24;
t4a=t4/24;
p.tmaxa=p.tmax/24;
%locs=locs/24;

[pks1,locs1] = findpeaks(c1(:,1),t1a);
[pks2,locs2] = findpeaks(c2(:,1),t2a);
[pks3,locs3] = findpeaks(c3(:,1),t3a);
[pks4,locs4] = findpeaks(c4(:,1),t4a);

ylim([-100 1690])
hold on
plot(locs1,pks1*1000,'.black', t1a,c1(:,2)*1000,'black','Linewidth',2);
plot(locs2,pks2*1000,'.b', t2a,c2(:,2)*1000,'--b','Linewidth',2);
plot(locs3,pks3*1000,'.r', t3a,c3(:,2)*1000,':r','Linewidth',2);
plot(locs4,pks4*1000,'.y', t4a,c4(:,2)*1000,'-.y','Linewidth',2);
xlim([0 p.tmaxa])

xlabel('Time [days]');
ylabel('Concentration [ng/mL]');
title('Dabrafenib concentration peaks');
legend('150 mg BID; central peak','150 mg BID; peripheral','100 mg BID; central peak','100 mg BID; peripheral','75 mg BID; central peak','75 mg BID; peripheral','50 mg BID; central peak','50 mg BID; peripheral','location','SouthEastoutside');
yyaxis right
ylim([-100 1690]/0.51956)
ylabel('Concentration [nM]');
grid on;


subplot(3,10,[17 18 19 20])

[pks1,locs1] = findpeaks(-c1(:,1),t1);
[pks2,locs2] = findpeaks(-c2(:,1),t2);
[pks3,locs3] = findpeaks(-c3(:,1),t3);
[pks4,locs4] = findpeaks(-c4(:,1),t4);



ylim([0 105])
hold on
plot(locs1/24,-pks1*1000,'oblack','Linewidth',1);
plot(locs2/24,-pks2*1000,'^b',    'Linewidth',1);
plot(locs3/24,-pks3*1000,'+r',   'Linewidth',1);
plot(locs4/24,-pks4*1000,'vy',   'Linewidth',1);
xlim([0 (p.tmax/24)])


xlabel('Time [days]');
ylabel('Concentration [ng/mL]');
title('Dabrafenib trough concentration');
legend('150 mg BID,central','100 mg BID,central','75 mg BID,central','50 mg BID,central','location','SouthEastOutside' );
yyaxis right
ylim([0 105]/0.51956)
ylabel('Concentration [nM]');
grid on;


[pks1b,locs1b] = findpeaks(-c1(:,2),t1);
[pks2b,locs2b] = findpeaks(-c2(:,2),t2);
[pks3b,locs3b] = findpeaks(-c3(:,2),t3);
[pks4b,locs4b] = findpeaks(-c4(:,2),t4);

tspan   = [ 24*20 24*20.5+p.tlag]; % Zeitintervall

p.D     = 150 ;%Dose Dabrafenib
c0      = [-pks1(length(locs1))  -pks1b(length(locs1b))];             % start values
[t1,c1] = ode15s(@dabra,tspan,c0,options,p);

p.D = 100 ;%Dose Dabrafenib
c0    = [-pks2(length(locs2))  -pks2b(length(locs2b))]; 
[t2,c2] = ode15s(@dabra,tspan,c0,options,p);

p.D = 75 ;%Dose Dabrafenib
c0    = [-pks3(length(locs3))  -pks3b(length(locs3b))]; 
[t3,c3] = ode15s(@dabra,tspan,c0,options,p);

p.D = 50 ;%Dose Dabrafenib
c0    = [-pks4(length(locs4))  -pks4b(length(locs4b))]; 
[t4,c4] = ode15s(@dabra,tspan,c0,options,p);

t1=t1-tspan(1);
t2=t2-tspan(1);
t3=t3-tspan(1);
t4=t4-tspan(1);

IntSS1 = trapz( t1(t1<12),c1(t1<12,1));
IntSS2 = trapz( t2(t2<12),c2(t2<12,1));
IntSS3 = trapz( t3(t3<12),c3(t3<12,1));
IntSS4 = trapz( t4(t4<12),c4(t4<12,1));
IntSS=[IntSS4 IntSS3 IntSS2 IntSS1];


subplot(3,10,[4 5 14 15])
ylim([-100 1690])
xlim([tspan]-tspan(1))
hold on
plot(t1,c1(:,1)*1000,'black', t1,c1(:,2)*1000,'black','Linewidth',2);
plot(t2,c2(:,1)*1000,'--b',   t2,c2(:,2)*1000,'--b','Linewidth',2);
plot(t3,c3(:,1)*1000,':r',    t3,c3(:,2)*1000,':r','Linewidth',2);
plot(t4,c4(:,1)*1000,'-.y',   t4,c4(:,2)*1000,'-.y','Linewidth',2);

xlabel('Time after day 20 [h]');
ylabel('Concentration [ng/mL]');
title('PK of Dabrafenib after steady state');
yyaxis right
ylim([-100 1690]/0.51956)
ylabel('Concentration [nM]');
grid on;

subplot(3,10,[27:30])
Int01 = trapz( t1(t1<12),c1(t1<12,1));
Int02 = trapz( t2(t2<12),c2(t2<12,1));
Int03 = trapz( t3(t3<12),c3(t3<12,1));
Int04 = trapz( t4(t4<12),c4(t4<12,1));
Int0=[Int04 Int03 Int02 Int01];
hold on
plot([100, 150, 200,300],Int0*1000,'-oblack','Linewidth',2);
plot([100, 150, 200,300],IntSS*1000,'--^b','Linewidth',2);
ylim([2000 10000])

xlabel('Total Daily Dose [mg]');
ylabel('AUC12 [ng/mL*h]');
legend('Day1, HPMC','Steady State','location','SouthEastoutside' );
grid on;

pos = get(h1,'Position');
set(h1,'PaperPositionMode','Auto','PaperUnits','points','PaperSize',[pos(3), pos(4)]);
export_fig('SFig1.pdf','-pdf');




end     


function dcdt=dabra(t,c,p)

nmax = floor(0.8*p.tmax/12);%maximal num of cycles

if t>p.tlag
    n=min([floor((t-p.tlag)/12) nmax]);
    Term=0;
    for i=1:(n+1)
        Term= Term + exp(-p.Ka*(t-(i-1)*12-p.tlag));
    end
else
    Term =0;
end

ClFind =  p.CLindSS*(p.D*p.Fgel/p.Dref)^p.y *(1-exp(-log(2)*t/p.T50)); %TermCL; % inducible clearence
ClF = p.CL0F + ClFind; %oral clearence

if t>p.tlag
dcdt(1) =   -(ClF)*c(1)/p.VcF - p.QF/p.VcF*(c(1)-c(2))+ p.Ka*p.D*Term/(p.VcF)     ;%     d[Cc]dt
else
dcdt(1) = 0;
end
dcdt(2) = +  p.QF/p.VpF*(c(1)-c(2))  -(ClFind)*c(2)/p.VpF    ;%     d[Cp]dt               
% 

dcdt = dcdt';   % important! - transposes the solution vector
end     
