#install.packages("ggplot")
#install.packages("ggpubr")
#install.packages("ggsignif")
#install.packages("RColorBrewer")
library(ggplot2)
library(ggpubr)
library(ggsignif)
library(RColorBrewer)

setwd("C:/Users/marco.albrecht/Documents/University_Luxembourg/Internships/Dresden/Imagequantification/Dabrafenib")
getwd()


# Multiple plot function
#
# ggplot objects can be passed in ..., or to plotlist (as a list of ggplot objects)
# - cols:   Number of columns in layout
# - layout: A matrix specifying the layout. If present, 'cols' is ignored.
#
# If the layout is something like matrix(c(1,2,3,3), nrow=2, byrow=TRUE),
# then plot 1 will go in the upper left, 2 will go in the upper right, and
# 3 will go all the way across the bottom.
#
multiplot <- function(..., plotlist=NULL, file, cols=1, layout=NULL) {
  library(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # If layout is NULL, then use 'cols' to determine layout
  if (is.null(layout)) {
    # Make the panel
    # ncol: Number of columns of plots
    # nrow: Number of rows needed, calculated from # of cols
    layout <- matrix(seq(1, cols * ceiling(numPlots/cols)),
                     ncol = cols, nrow = ceiling(numPlots/cols))
  }
  
  if (numPlots==1) {
    print(plots[[1]])
    
  } else {
    # Set up the page
    grid.newpage()
    pushViewport(viewport(layout = grid.layout(nrow(layout), ncol(layout))))
    
    # Make each plot, in the correct location
    for (i in 1:numPlots) {
      # Get the i,j matrix positions of the regions that contain this subplot
      matchidx <- as.data.frame(which(layout == i, arr.ind = TRUE))
      
      print(plots[[i]], vp = viewport(layout.pos.row = matchidx$row,
                                      layout.pos.col = matchidx$col))
    }
  }
}





mydata = read.csv("DResult.csv")
head(mydata)

#mydata[,"AreaRel"]<- sqrt(mydata[,"AreaRel"]/pi) #from area to radius

df = as.data.frame(matrix( NA, nrow=nrow(mydata), ncol=6, byrow = TRUE))
colnames(df)=c("Replicate","gelType","d0d","d4d","d6d","nM.Dabra")

# extract groups from identifier
for (i in 1:nrow(mydata)){
  df[i,"Replicate"]<-strsplit(as.character(mydata[i,"Identifier"]),"_")[[1]][5]
  if( grepl("CD2",as.character(mydata[i,"Identifier"]))     ){df[i,"gelType"]<-"CD2"}
  if( grepl("CD6",as.character(mydata[i,"Identifier"]))     ){df[i,"gelType"]<-"CD6"}
  timp<-c(0,4,6)
  for (m in 1:3){if( grepl(paste0("_d",timp[m],"_") ,as.character(mydata[i,"Identifier"]))){df[i,paste0("d",timp[m],"d")]<-mydata[i,"TotalArea"]}}
  df[i,"nM.Dabra"]<-strsplit(as.character(mydata[i,"Identifier"]),"_")[[1]][4]
} 
head(df)


# restructure data to time course and normalize to the first value
RepN<-unique(with(df, paste0(Replicate,"_",gelType)))
RepN<-unique(df[,c("Replicate","gelType")])
A<-B<-C<-D<-0
for (i in 1:nrow(RepN)){
    
   # CD2
    A<- df[ (df[,"Replicate"] ==RepN[i,1] & df[,"gelType"] =="CD2" ),]
    A$d0d<-A$d0d[!is.na(A$d0d) ]
    A$d4d<-A$d4d[!is.na(A$d4d) ]
    A$d6d<-A$d6d[!is.na(A$d6d) ]
    A<-A[!duplicated(A), ]
    #A[,c("d0d","d4d","d6d")]<-A[,c("d0d","d4d","d6d")]/as.numeric(A[,"d0d"]) # normalize to starting point
    A$d6d<- A$d6d/A$d4d #normalize     
    A$d4d<- A$d4d/A$d0d #normalize    
    A$d0d<- A$d0d/A$d0d #normalize (just a unnecessary check)
    
    # CD6
    B<- df[ (df[,"Replicate"] ==RepN[i,1] & df[,"gelType"] =="CD6" ),]
    B$d0d<-B$d0d[!is.na(B$d0d) ]
    B$d4d<-B$d4d[!is.na(B$d4d) ]
    if(!identical(B$d6d[!is.na(B$d6d)], numeric(0))){ B$d6d<-B$d6d[!is.na(B$d6d) ]} # because one value is missing as one spheroid leaved the gel
    B<-B[!duplicated(B), ]
    B$d6d<- B$d6d/B$d4d #normalize
    B$d4d<- B$d4d/B$d0d #normalize
    B$d0d<- B$d0d/B$d0d #normalize (just a unnecessary check)
    # merge
    if (i==1){
      D <-rbind(A,B)
    }else{
      C <-rbind(A,B)
      D <-rbind(C,D)
      rm(C)
    }
    rm(A,B)
    D<-D[!duplicated(D), ]
}


## Group data in cases
  D000CD2<-D[D[ , "nM.Dabra"]=="D000" & D[ , "gelType"]=="CD2", ]
  D010CD2<-D[D[ , "nM.Dabra"]=="D010" & D[ , "gelType"]=="CD2", ]
  D050CD2<-D[D[ , "nM.Dabra"]=="D050" & D[ , "gelType"]=="CD2", ]
  D100CD2<-D[D[ , "nM.Dabra"]=="D100" & D[ , "gelType"]=="CD2", ]
  
  D000CD6<-D[D[ , "nM.Dabra"]=="D000" & D[ , "gelType"]=="CD6", ]
  D010CD6<-D[D[ , "nM.Dabra"]=="D010" & D[ , "gelType"]=="CD6", ]
  D050CD6<-D[D[ , "nM.Dabra"]=="D050" & D[ , "gelType"]=="CD6", ]
  D100CD6<-D[D[ , "nM.Dabra"]=="D100" & D[ , "gelType"]=="CD6", ]

  D000<-D[D[ , "nM.Dabra"]=="D000" , ]
  D010<-D[D[ , "nM.Dabra"]=="D010" , ]
  D050<-D[D[ , "nM.Dabra"]=="D050" , ]
  D100<-D[D[ , "nM.Dabra"]=="D100" , ]
  
  
  CD2 <-rbind(data.frame(x = D000CD2[,"d4d"], y =  "4d (0.5 kPa)         "),
              data.frame(x = D000CD2[,"d6d"], y =  "6d (0.5 kPa) +   0 nM"),
              data.frame(x = D010CD2[,"d6d"], y =  "6d (0.5 kPa) +  10 nM"),
              data.frame(x = D050CD2[,"d6d"], y =  "6d (0.5 kPa) +  50 nM"),
              data.frame(x = D100CD2[,"d6d"], y =  "6d (0.5 kPa) + 100 nM"))
  head(CD2)
  
  CD6 <-rbind(data.frame(x = D000CD6[,"d4d"],  y = "4d (4.3 kPa)"),
              data.frame(x = D000CD6[,"d6d"],  y = "6d (4.3 kPa) +   0 nM"),
              data.frame(x = D010CD6[,"d6d"],  y = "6d (4.3 kPa) +  10 nM"),
              data.frame(x = D050CD6[,"d6d"],  y = "6d (4.3 kPa) +  50 nM"),
              data.frame(x = D100CD6[,"d6d"],  y = "6d (4.3 kPa) + 100 nM"))
  head(CD6)
  
  CD26<-rbind(CD6,CD2)
  CD26<-CD26[!is.na(CD26[,"x"]),]
  
  Both<-rbind(data.frame(x = D000[,"d4d"], y = "4d (both)"),
              data.frame(x = D000[,"d6d"], y = "6d (both) +   0 nM"),
              data.frame(x = D010[,"d6d"], y = "6d (both) +  10 nM"),
              data.frame(x = D050[,"d6d"], y = "6d (both) +  50 nM"),
              data.frame(x = D100[,"d6d"], y = "6d (both) + 100 nM"))
  head(Both)
  Both<-Both[!is.na(Both[,"x"]),]

  
  compareCD26<-list( c("6d (4.3 kPa) +   0 nM", "6d (4.3 kPa) +  10 nM"),
                     c("6d (4.3 kPa) +   0 nM", "6d (4.3 kPa) +  50 nM"),
                     c("6d (4.3 kPa) +   0 nM", "6d (4.3 kPa) + 100 nM"),
                     c("6d (4.3 kPa) +  10 nM", "6d (4.3 kPa) +  50 nM"),
                     c("6d (4.3 kPa) +  10 nM", "6d (4.3 kPa) + 100 nM"),
                     c("6d (0.5 kPa) +   0 nM", "6d (0.5 kPa) +  10 nM"),
                     c("6d (0.5 kPa) +   0 nM", "6d (0.5 kPa) +  50 nM"),
                     c("6d (0.5 kPa) +   0 nM", "6d (0.5 kPa) + 100 nM"),
                     c("6d (0.5 kPa) +  10 nM", "6d (0.5 kPa) +  50 nM"),
                     c("6d (0.5 kPa) +  10 nM", "6d (0.5 kPa) + 100 nM"))
  

  Plotcolor<-c('burlywood1',"darkolivegreen4","darkolivegreen3","darkolivegreen2","darkolivegreen1",'burlywood1','darkslategray4','darkslategray3','darkslategray2','darkslategray1')
  
  pointcolor= 1:nrow(CD26)*NA
  for (i in 1:nrow(CD26)){ 
   if( CD26$y[i]=="4d (0.5 kPa)         " |  CD26$y[i]=="4d (4.3 kPa)" ){ pointcolor[i]=Plotcolor[1]}
    
   if( CD26$y[i]=="6d (0.5 kPa) +   0 nM"                           ){ pointcolor[i]=Plotcolor[7]}
   if( CD26$y[i]=="6d (0.5 kPa) +  10 nM"                           ){ pointcolor[i]=Plotcolor[8]}
   if( CD26$y[i]=="6d (0.5 kPa) +  50 nM"                           ){ pointcolor[i]=Plotcolor[9]}
   if( CD26$y[i]=="6d (0.5 kPa) + 100 nM"                           ){ pointcolor[i]=Plotcolor[10]}
    
    if( CD26$y[i]=="6d (4.3 kPa) +   0 nM"                           ){ pointcolor[i]=Plotcolor[2]}
    if( CD26$y[i]=="6d (4.3 kPa) +  10 nM"                           ){ pointcolor[i]=Plotcolor[3]}
    if( CD26$y[i]=="6d (4.3 kPa) +  50 nM"                           ){ pointcolor[i]=Plotcolor[4]}
    if( CD26$y[i]=="6d (4.3 kPa) + 100 nM"                           ){ pointcolor[i]=Plotcolor[5]}
    }
  pointcolor
  
  

ggplot(data=CD26, aes(x = y, y = x)) +
geom_boxplot(fill=Plotcolor)+
scale_x_discrete(name = "condition",limits=c(levels(CD26$y),""))+
scale_y_continuous(name = "area change")+
theme_classic(base_size = 16) +
theme(axis.text.x=element_text(angle=-30,hjust=0,size=10))+
geom_dotplot(fill=pointcolor,binaxis='y', stackdir='center',binwidth=0.1)+
geom_signif(y_position=c(3.8,3.5,3.2,2.2,1.8,3.8,3.5,3.2,2.2,1.8), test="t.test",comparisons = compareCD26,map_signif_level=TRUE)

  
compareCDBoth<-list(c("6d (both) +   0 nM", "6d (both) +  10 nM"),
                    c("6d (both) +   0 nM", "6d (both) +  50 nM"),
                    c("6d (both) +   0 nM", "6d (both) + 100 nM"),
                    c("6d (both) +  10 nM", "6d (both) +  50 nM"),
                    c("6d (both) +  10 nM", "6d (both) + 100 nM"))
  
PlotcolorBoth<-c('burlywood1',"deepskyblue4","deepskyblue3","deepskyblue2","deepskyblue1")

pointcolorBoth= 1:nrow(Both)*NA
for (i in 1:nrow(Both)){ 
  if( Both$y[i]=="4d (both)"                                ){ pointcolorBoth[i]=PlotcolorBoth[1]}
  if( Both$y[i]=="6d (both) +   0 nM"                       ){ pointcolorBoth[i]=PlotcolorBoth[2]}
  if( Both$y[i]=="6d (both) +  10 nM"                       ){ pointcolorBoth[i]=PlotcolorBoth[3]}
  if( Both$y[i]=="6d (both) +  50 nM"                       ){ pointcolorBoth[i]=PlotcolorBoth[4]}
  if( Both$y[i]=="6d (both) + 100 nM"                       ){ pointcolorBoth[i]=PlotcolorBoth[5]}
}
pointcolorBoth


ggplot(data=Both, aes(x = y, y = x)) +
  geom_boxplot(fill=PlotcolorBoth)+
  scale_x_discrete(name = "condition",limits=c(levels(Both$y),""))+
  scale_y_continuous(name = "area change")+
  theme_classic(base_size = 16) +
  theme(axis.text.x=element_text(angle=-30,hjust=0,size=10))+
  geom_dotplot(fill=pointcolorBoth,binaxis='y', stackdir='center',binwidth=0.1)+
  geom_signif(y_position=c(3.8,3.5,3.2,2.2,1.8,3.8,3.5,3.2,2.2,1.8), test="t.test",comparisons =  compareCDBoth,map_signif_level=TRUE)



ALL<-rbind(CD26,Both)

ggplot(data=ALL, aes(x = y, y = x)) +
  geom_boxplot(fill=c(Plotcolor,PlotcolorBoth))+
  scale_x_discrete(name = "condition",limits=c(levels(ALL$y),""))+
  scale_y_continuous(name = "area change")+
  theme_classic(base_size = 16) +
  geom_vline(xintercept=c(1.5, 5.5, 6.5, 10.5, 11.5 ,15.5) ,color="gray", linetype=c(5,1,5,1,5,1),size=c(0.5,1.2,0.5,1.2,0.5,1.2))+
  theme(axis.text.x=element_text(angle=-30,hjust=0,size=10,face="bold"),
        axis.line = element_line(size = 1))+
  geom_dotplot(fill=c(pointcolor,pointcolorBoth),binaxis='y', stackdir='center',binwidth=0.08)+
  geom_signif(y_position=c(3.8,3.5,3.2,2.2,1.8,3.8,3.5,3.2,2.2,1.8,3.8,3.5,3.2,2.2,1.8), test="t.test",comparisons =c( compareCD26, compareCDBoth), map_signif_level=TRUE)



#, plot = multiplot(p1, p2, p3, p4, cols=2


ggsave(paste0(getwd(),"/dabraImpactResult.pdf"), device = "pdf", path = NULL,
       scale = 5, width = 8, height = 5, units = "cm",
       dpi = 1200, limitsize = TRUE)
